15.68. cdist-type__install_reboot(7) — cdist 4.10.4 documentation

# 15.68. cdist-type__install_reboot(7)

## 15.68.1. NAME

cdist-type__install_reboot - run reboot

## 15.68.2. DESCRIPTION

This cdist type allows you to reboot a machine.

## 15.68.3. REQUIRED PARAMETERS

None

## 15.68.4. OPTIONAL PARAMETERS

None

## 15.68.5. EXAMPLES

    __install_reboot

## 15.68.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 15.68.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.